@@ -1,7 +1,7 @@
 
 
 def number_to_percent(number, precision=2):
-    return round(number * 100, precision)
+    return "%.2f%%" % round(number * 100, precision)
 
 
 def number_format(number):
