@@ -14,7 +14,7 @@ csrf = SeaSurf(app)
 
 js = Bundle('js/jquery.js', 'js/d3.js',
             'js/bootstrap.js', 'js/experiment.js', 'js/chart.js',
-            'js/script.js', 'js/underscore-min.js', 'js/spin.min.js',
+            'js/sixpack.js', 'js/underscore-min.js', 'js/spin.min.js',
             'js/waypoints.min.js',
             filters=['closure_js'],
             output="{0}/sixpack.js".format(cfg.get('asset_path', 'gen')))
@@ -32,9 +32,6 @@ assets.register('css_all', css)
 # List of experiments
 @app.route("/")
 def hello():
-    #archived = bool(request.args.get('include_archived', False))
-    #exclude_archived = not archived
-    # TODO: these need to be sorted
     experiments = Experiment.all_names(REDIS)
     return render_template('dashboard.html', experiments=experiments)
 
